package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(T``````````0```````
M`,&@``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````+C@````````N.``
M```````0``````$````&````````N[````````#+L````````,NP````````
M!-`````````4^````````!```````@````8```````"[P````````,O`````
M````R\`````````"$`````````(0``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````L?0```````"Q]````````+'T`````````.0`````````Y```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+NP````````R[``````
M``#+L`````````10````````!%```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`KN-J\:JJ*&2*!Z6L1;+8\:@BR($````$````$```
M``%'3E4```````````,````"```````````````1````10````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND40H(@`````````10```$@```!+
M````3````%,```!4````50```%<```!8````6@```%L```!<````70```%\`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B9[B%`WMVV(RGN/-
MV\PEC!4+ESH-FYRI?PH"I^!0GAIK2?O@HP``````````````````````````
M```````````#```+````````&:@``````````````YX2````````````````
M`````````````-P2`````````````````````````````LH1````````````
M`````````````````FD2`````````````````````````````(,2````````
M`````````````````````-$1`````````````````````````````C<2````
M`````````````````````````542`````````````````````````````<H2
M`````````````````````````````/(2````````````````````````````
M`;<2`````````````````````````````A42````````````````````````
M``````$@`````````````````````````````E@2````````````````````
M`````````6P2`````````````````````````````M(2````````````````
M`````````````LDA`````````````````````````````9L2````````````
M`````````````````AP2`````````````````````````````2,2````````
M`````````````````````@X2`````````````````````````````1,2````
M`````````````````````````042`````````````````````````````J<2
M`````````````````````````````<(2````````````````````````````
M`!`@`````````````````````````````7,2````````````````````````
M`````G`2`````````````````````````````L@1````````````````````
M`````````D42`````````````````````````````?D2````````````````
M`````````````"P@`````````````````````````````$82````````````
M`````````````````?$2`````````````````````````````442````````
M`````````````````````@<2`````````````````````````````&,2````
M`````````````````````````,`2`````````````````````````````'02
M`````````````````````````````H`2````````````````````````````
M`HHB`````````````````````````````8H2````````````````````````
M`````;T2`````````````````````````````*02````````````````````
M`````````>L2`````````````````````````````@`2````````````````
M`````````````3<2`````````````````````````````.82````````````
M`````````````````=,2`````````````````````````````GD2````````
M`````````````````````B(2`````````````````````````````K82````
M`````````````````````````>02`````````````````````````````:,2
M`````````````````````````````(\2````````````````````````````
M`842`````````````````````````````6`2````````````````````````
M`````.$2`````````````````````````````7X2````````````````````
M`````````+,1`````````````````````````````J\2````````````````
M`````````````ID2`````````````````````````````2P2````````````
M`````````````````E`2`````````````````````````````%02````````
M`````````````````````C`2`````````````````````````````F(1````
M`````````````````````````Z<2```-````````5&`````````$:```!`P2
M```-````````0/`````````/N@```L,2```-````````(/`````````"2```
M`PX2```-````````+;``````````!@```SP2```-````````4+`````````#
MJ```!#(2```-````````+<`````````#-````_(0```7````````T(``````
M`````````Q\2```-````````,0``````````4````U(2```-````````/@``
M````````W@```[,1```/````````<UP`````````!````\\2```-````````
M<!`````````!,````]H2```-````````+(``````````/```!`<0```7````
M````X*@`````````````!"`2```-````````/Q`````````!W````\(0```6
M````````T````````````````W82```-````````,5`````````!;@``!!D0
M```6````````T(``````````````!#\1```6````````T'@`````````"```
M`RP2```-````````<Q```````````@```\@2```-````````(T``````````
M`````^(2```-````````<J``````````8@```_X2```-````````;Z``````
M````;````\0@```6````````T````````````````XP2```-````````/N``
M````````+````V`2```-````````+,``````````[@```X(2```-````````
M<4`````````!5```!$D2```-````````,L`````````+,@!?7V=M;VY?<W1A
M<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E
M<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E
M<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP
M`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K
M-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M
M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R<W1R`')M9&ER`%]?9G!R
M:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N
M9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R
M96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E
M`&%C8V5S<P!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C
M+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S
M=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN
M7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?7VQI8F-?
M8W-U7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D
M:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`$=,24)#7S(N,@!'3$E"0U\R+C0`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXS+C0````````"`````@`"```````#`````@````0`
M`@````(``@`%``(`!``"`````@```````@`"```````"``(``@`"```````"
M`````@`````````"``(`!``"`````@`"```````&``(`!@`"``(`!`````0`
M```"``0````"``8````"`````@`"``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``````````$``0```O0`
M```0````(`UI:1(````$```$5@```````0`$```#!````!``````#6EI%```
M``8```1@````$`EI&7(````%```$:@```!`):1ET`````P``!'8````0#6EI
M$@````(```16`````````````,NP``````````P````````D8````````,NX
M``````````P````````D$````````,_X``````````P````````@\```````
M`-`(``````````P```````#0"````````-`8``````````P```````!S8```
M`````-`@``````````P```````!S9@```````-`P``````````P```````!S
M:````````-`X``````````P```````!S;````````-!```````````P`````
M``!S=````````-!(``````````P```````!S[````````-!0``````````P`
M``````!S?````````-!@``````````P```````!S@````````-!H````````
M``P```````!SA@```````-!X``````````P```````!V2````````,^@````
M!`````H``````````````````,^H````!P````H``````````````````,^P
M````"P````H``````````````````,^X````#@````H`````````````````
M`,_`````&P````H``````````````````,_(````(0````H`````````````
M`````,_0````)`````H``````````````````,_8````)@````H`````````
M`````````,_@````*@````H``````````````````,_H````/0````H`````
M`````````````,_P````1`````H``````````````````,WH`````@````L`
M`````````````````,WP`````P````L``````````````````,WX````!0``
M``L``````````````````,X`````!@````L``````````````````,X(````
M"`````L``````````````````,X0````"0````L``````````````````,X8
M````"@````L``````````````````,X@````#`````L`````````````````
M`,XH````#0````L``````````````````,XP````#P````L`````````````
M`````,XX````$`````L``````````````````,Y`````$0````L`````````
M`````````,Y(````$P````L``````````````````,Y0````%`````L`````
M`````````````,Y8````%0````L``````````````````,Y@````%@````L`
M`````````````````,YH````%P````L``````````````````,YP````&```
M``L``````````````````,YX````&0````L``````````````````,Z`````
M&@````L``````````````````,Z(````'`````L``````````````````,Z0
M````'0````L``````````````````,Z8````'P````L`````````````````
M`,Z@````(`````L``````````````````,ZH````(@````L`````````````
M`````,ZP````(P````L``````````````````,ZX````)0````L`````````
M`````````,[`````)P````L``````````````````,[(````*`````L`````
M`````````````,[0````*0````L``````````````````,[8````*@````L`
M`````````````````,[@````*P````L``````````````````,[H````+```
M``L``````````````````,[P````+0````L``````````````````,[X````
M+@````L``````````````````,\`````+P````L``````````````````,\(
M````,`````L``````````````````,\0````,0````L`````````````````
M`,\8````,@````L``````````````````,\@````,P````L`````````````
M`````,\H````-`````L``````````````````,\P````-0````L`````````
M`````````,\X````-@````L``````````````````,]`````-P````L`````
M`````````````,](````.`````L``````````````````,]0````.0````L`
M`````````````````,]8````.@````L``````````````````,]@````.P``
M``L``````````````````,]H````/`````L``````````````````,]P````
M/@````L``````````````````,]X````/P````L``````````````````,^`
M````0`````L``````````````````,^(````00````L`````````````````
M`,^0````0@````L``````````````````,^8````0P````L``````````.MO
M\#``)+D$`!^G^_]@XQ#P```DP,```%H*P!```%K[XQ`0```$N0(`$:>$``,-
MX>-`\1``!.MO\-``!`?T!P?C$/`X`"3`$```6?'2!_`P$`CC$!`0``0'\0<`
M!P`'`,`0``!9\.,0$```!`?Q#1#C$!`,`!3`]/___^4`````P!```%GDXQ`0
M```$!_$-$.,0$`P`%,#T____U0```!C`$```6=CC$!````0'\0T0XQ`0#``4
MP/3____%````,,`0``!9S.,0$```!`?Q#1#C$!`,`!3`]/___[4```!(P!``
M`%G`XQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```6;3C$!````0'\0T0
MXQ`0#``4P/3___^5````>,`0``!9J.,0$```!`?Q#1#C$!`,`!3`]/___X4`
M``"0P!```%F<XQ`0```$!_$-$.,0$`P`%,#T____=0```*C`$```69#C$!``
M``0'\0T0XQ`0#``4P/3___]E````P,`0``!9A.,0$```!`?Q#1#C$!`,`!3`
M]/___U4```#8P!```%EXXQ`0```$!_$-$.,0$`P`%,#T____10```/#`$```
M66SC$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!98.,0$```!`?Q#1#C
M$!`,`!3`]/___R4```$@P!```%E4XQ`0```$!_$-$.,0$`P`%,#T____%0``
M`3C`$```64CC$!````0'\0T0XQ`0#``4P/3___\%```!4,`0``!9/.,0$```
M!`?Q#1#C$!`,`!3`]/___O4```%HP!```%DPXQ`0```$!_$-$.,0$`P`%,#T
M___^Y0```8#`$```623C$!````0'\0T0XQ`0#``4P/3___[5```!F,`0``!9
M&.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```%D,XQ`0```$!_$-$.,0
M$`P`%,#T___^M0```<C`$```60#C$!````0'\0T0XQ`0#``4P/3___ZE```!
MX,`0``!8].,0$```!`?Q#1#C$!`,`!3`]/___I4```'XP!```%CHXQ`0```$
M!_$-$.,0$`P`%,#T___^A0```A#`$```6-SC$!````0'\0T0XQ`0#``4P/3_
M__YU```"*,`0``!8T.,0$```!`?Q#1#C$!`,`!3`]/___F4```)`P!```%C$
MXQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```6+CC$!````0'\0T0XQ`0
M#``4P/3___Y%```"<,`0``!8K.,0$```!`?Q#1#C$!`,`!3`]/___C4```*(
MP!```%B@XQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`$```6)3C$!````0'
M\0T0XQ`0#``4P/3___X5```"N,`0``!8B.,0$```!`?Q#1#C$!`,`!3`]/__
M_@4```+0P!```%A\XQ`0```$!_$-$.,0$`P`%,#T___]]0```NC`$```6'#C
M$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!89.,0$```!`?Q#1#C$!`,
M`!3`]/___=4```,8P!```%A8XQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`
M$```6$SC$!````0'\0T0XQ`0#``4P/3___VU```#2,`0``!80.,0$```!`?Q
M#1#C$!`,`!3`]/___:4```-@P!```%@TXQ`0```$!_$-$.,0$`P`%,#T___]
ME0```WC`$```6"CC$!````0'\0T0XQ`0#``4P/3___V%```#D,`0``!8'.,0
M$```!`?Q#1#C$!`,`!3`]/___74```.HP!```%@0XQ`0```$!_$-$.,0$`P`
M%,#T___]90```\#`$```6`3C$!````0'\0T0XQ`0#``4P/3___U5```#V,`0
M``!7^.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!```%?LXQ`0```$!_$-
M$.,0$`P`%,#T___]-0``!`C`$```5^#C$!````0'\0T0XQ`0#``4P/3___TE
M```$(,`0``!7U.,0$```!`?Q#1#C$!`,`!3`]/___14```0XP!```%?(XQ`0
M```$!_$-$.,0$`P`%,#T___]!0``!%#`$```5[SC$!````0'\0T0XQ`0#``4
MP/3___SU```$:,`0``!7L.,0$```!`?Q#1#C$!`,`!3`]/___.4```2`P!``
M`%>DXQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```5YCC$!````0'\0T0
MXQ`0#``4P/3___S%```$L,`0``!7C.,0$```!`?Q#1#C$!`,`!3`]/___+4`
M``3(P!```%>`XQ`0```$!_$-$.,0$`P`%,#T___\I0``!.#`$```5W3C$!``
M``0'\0T0XQ`0#``4P/3___R5```$^,`0``!7:.,0$```!`?Q#1#C$!`,`!3`
M]/___(4```40``````````#K;_`P`"2R3P"PX_#_./]QXS#PJ``DXT#PH``D
M4"#PM.N[`"``#;)/`+%!0/"@T@?PP+`H03#PJ$$@\+3`Y?___[[$2```5S_$
M*```5U"Y!``TP.4``"COQ!@``%=0E0`0`*>$`*C$J```5RGC(*```!;`Y?__
M_P.Y!``2XR"@```6E@(4BL#E___^^5B@\+26`22*["H`!`#8N10`(NLB``,`
M#<#E____&N,P\*@`!%B0\+3C$#````3$*P``5W/C$"```"3`$```*D7C$"`(
M`"3$&```5UNGJ@`#XQ`@$``DP!```"HYXQ`@&``DN00`4NR<`)\!?D$P,`BG
M"``$[$G__P#8XR`P```$N10`$.L1``,`#>,A4```)*<*``&G.P`(IT;_\>P9
M``,`V,0H``!70;D4`!'K$0`#``U!$5``Y4@0````N10`2J=I``#`,````Q#`
MY?___#$8HNPH`$,`?L0H``!7)D&0\+S`Y?___A6Y!``YP"```"CHP.4```$!
M["@`.0!\Q"@``%<3P.7___O4P.7___U!U0?PP+`HN10`*J=T`$[K;_#X``0'
M_L#E___\\\0K``!6_.PH`#T`?,#E___]:L2H``!6=^,@H```%L#E___^49(`
M*CFG]/]&Q"@``%;FP.7___QW&**G]/^YP!```%;9XR`0```"IX0`!\#E```8
MM:?T_[^Y!``YP"```"ARP.4```"SQ"L``%;$["C_L@!\I_3_[:<8``2G]/]]
MIRD``<#E___];L#E___]RP<'!P<'!P<'04#P".,P\```!*<)__"Y@`#PI_O_
M4-<'\`#P`.OO\*``)$%P\*#`8```)]7`4```)YK`(```5D/C("````3`Y?__
M_=4```<'!P<'!P<'!P?`$```5GC`(```5G7L$@`*@&3$&```5@_L&``$`'P'
M\0?^!P<'!P<'!P<'!P<'!P?`$```5F#`,```5EVY"0`QZQ,``P`*ZS,`/P`,
MN0@`,>LS``$`"NPX``T`?,08``!5[NP8``<`?,`@``!61`?Q!_X'!P<'!P<'
M!P<'!P<'!^N_\%@`),"P``!6->/P_V#_<94`L`"G=``5P!```%7;XQ`0```"
MIX0`",0H``!5Y\#E___\Q,#E____I9(!L`#KO_#X``0'_@<'!P<'!P<'P/3_
M__^P!P<'!P<'!P<'!^MO\#``)./P_UC_<>PH`%\`?,08``!5C^-P$````J>$
M`%:Y!`""XR`@``"0N00`8[D$`)@8$NPH`%(`?$(0\*>5/?"GIX0`"^,@D`$`
MD$&0D`$8$NPF__0`?!N8XZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY!``J
MP.7___N_["8`"0!^01F@`)4]$`"GA``/0;"P"..@L````J=T_^FY!``JZV_P
MV``$!_ZYZ7`;0:F@`>L1``,`"E`08`"Y!``JZV_PV``$!_ZGJ0``N00`*NMO
M\-@`!`?^IY@``*?T_[\'!P<'!P<'!P<'!P<'!^MO\#``)+)/`*#C\/[`_W'K
MJ@`@``VR3P"AT@?Q.*`H["@`"0!\N00`8I4`(`"G=``+U0?Q.*`HIW0`B.MO
M\7``!`?^P.7___URN00`LNPH__(`?.R&/+\`54'0\*BG>0`/N00`*\#E___[
M\>PH`%0`?$&0(!.5+B`3IW0`!I4`D`&GA/_PE2X@$Z>$`%&G&0``[(@`5P!\
MN>F`-^<#8```-Z<;`!#G```P`(&GA``,YP%@```&IQL`$.<``#``@:=T__CG
M0``'`"&YA`!$N2``0T$P,`&YXB`3IR0`,^-!3_#_<:<Y``#L&3R_`%6GA``P
MN>D0%^<!(!,`-Z<[`!#G```P`(&GA``HYP,@$P`&I_3_]KD$`"O`Y?__^BBY
M!``FP.7___J3I_3_A94ND`&G=/^OE0"0`J>$_Y6G]/^IISD`#Z?T_[;`Y?__
M_!"G&0`/I_3_W.=0``<`(;F$`%6Y(`!101`0`;GB(#&G)/_QXR-?\/]Q&B2G
M*@`"N10`(L#E___Z-..0\*``)*=)__^Y!`"2ISD``<!0```F3,#E___\I;D$
M`$VY!``YIRD``<#E___Z#.PH``W_?E@0\,"G*$``P!L``/``[!(`#X!VN00`
M*<#E___\"KD$`"G`Y?___%6G]/\_N00`*<#E____"J?T__0'!P<'!P<'!P<'
MZW_P.``DX_#P`/]QXP#_^``@LD\`@./P_UC_<>N(`"``#;)/`('C$/"@`7'2
M!Q``@"BY!`"C09#PH+D$`+*Y!``YITD/_\`@```E^,#E___Z?NPL`#$`?NP2
M__\`V+D4`'%!-_"@E0`P`*=T`$'L&``C`'ZY!`!'N00`*:<Y`"_`Y?__^H3L
M*``7`'S$&```4][C(!```!;`Y?__^[BY!`!7N00`2;D$`#O`Y?__^P^G]``2
MQ!@``%/*XR`0```6P.7___NDN00`2KD$`#O`Y?__^?WC$/"@`7'5!Q``@"BG
M=``*ZW_PX`$$!_ZY%`!RI_3_PL#E___[.@<'!P<'!^MO\#``),2X``!3H>/P
M_UC_<>,@L```%L!@```FX\#E___[=>,@L```%L#E___[;\1(``!3H,!0``!$
MF<`P```EA<#E___[X^,@L```%L#E___[7>5(\*```+D$`%;`0```$_G`,```
M)7_`Y?__^D_K;_#8``0'_@<'!P<'!P<'ZV_P,``DN00`[^/P_T#_<:?K__A@
M@.``N00`HKD$`).5/3``IW0`!$&0,`&G*0``[#D\OP!5IX0!)J<9``^Y"0`3
MYP&0```WIRL`$.<``#``@:>$``SG`I````:G*P`0YP``,`"!IW3_^.<P``<`
M(;F$`#.Y(``Q01`0`;GB("&G)`$!Q$@``%,>XR(_\/]Q:(!``.,@\+``).,0
MH```D+/-`"CC0/"H`"3C<"````08@:?8``#L&``5`'RY!`#:0A#PIY4]\*>G
MA``+XR#0`0"00=#0`1@2[";_]`!\&]KL>`%$`'RSS0"XN10`;;D$`$:Y!``Z
MN00`)\#E___Y1^PF``D`?D$6<`"5/1``IX0`OD&PL`CC<+````*G=/_IL\T`
M&*>(```8**>*``%!$!`(XS`0```"IW3_^*<J``.Y%``BZR(``P`-P!```%,O
MXQ`0```2IX0`Y[D$`#*SS0`HP.7___ESXQ#PJ``$N00`<N,@$```).PH`'\`
M?+D4`+CKNP`#``VGB@`!N10`B.N(``,`#4$8<`#E2!````#C$/"H``1#@*``
M:(`0`+F4`"BY!``:IX$`_Z=T``ZG]`#;XR`0`0"001`0`>PH``@`?+F4`"+L
M)O_V/7ZY"0`:N10`$>,@\+``!$$B$`+`Y?__^#VSS0`8XRL0```D["@`/`!\
MXQ#PJ``$0:"@`>,@$```!.,0K___D.,K(```!!A!0A`@`.P6`!``?*?T`'3C
M$*```)!!H*`!0A`P`1A![!@`:@!\0D#PI[D$`#*5/?"G02`@`:=T_^V2/3``
MIQD``.,AD```D$(A,`&G&P`![";_^0!\:(#PN.MO\/``!`?^IQD`#Z?T_NA!
M-G`!IQD``.Q#/+\`5:>$`$*G*0`/N0D`).<",```-Z<;`!#G```P`(&GA``,
MYP$P```&IQL`$.<``#``@:=T__CG0``'`"&YA`!$N2``0D$@(`&YXB`2IR0`
M'>,@\+``!.,13_#_<>P2`$6@9;/-`!BY"0"QZ[L``P`*N10`N^N[``,`#:?T
M_T^Y!``RI_3_H:<I``^G]/_,P!```%)"Y4P0```!P.7___><N00`<NPH_YX`
M?+/-`#BY%`"XZ[L``P`-N00`2\#E___X"^,0\*@`!.-P$```)*?T_Q*G*0`0
MIX@``*?T_NVG&0``I_3_-J<9``#C(9```)!"(3``IQL``>PF__D`?&B`\+CK
M;_#P``0'_NOO\'``),08``!1D>/P_V#_<>,@$```%L#E___Y:,1(``!1F<!0
M``!"DL`P```C?NOO\1``!,#T___YV0<'!P?K;_`P`"3C\/``_W'C`/_X`"#C
M\/``_W'C`/_X`""R3P"0X_#_2/]QZYD`(``-LD\`D>,0\+`"<=('$`"0*,#E
M___XM<`0```C<.,0\*``)$&P\*ZY!`!BITD0`:<Y``&Y!``KP%```"-:P.7_
M__F/XX#PKP%QN00`*[D$`#BG21``P.7___>S["0`+`!^N00`LJ<J``&Y%``B
MP.7___;WN00`HNPH`!``?+D4`+NY!``XN00`2\#E___YJ4$;H`"2`!``XQ#P
ML`)QU0<0`)`HIW0`#+D$`"KK;_#H`@0'_J>I``"G]/_PP.7___B0!P?`]/__
M_X@'!P<'!P<'!P<'ZV_P,``DX_#P`/]QXP#_^``@LD\`D./P_KC_<>N9`"``
M#;)/`)'C$/%``7'2!Q``D"C$&```4->Y!`""N00`<^.@$````J>$`/VG*`!!
MP!```"+M01`0`;F4`"+L*``&`'[L)@%B/7[`(```(N"Y"0`2X["@```"IX0`
M'KD4`&&Y!`!&N00`*\`P```BT,#E___W#>PF``D`?D$6L`"5/1``IX0`QT&@
MH`CCL*````*G=/_HN00`**<Y`"_`Y?__^#;L*``9`'S`(```(K6Y!``XP.7_
M__TGN00`*.,0\4`!<=4'$`"0**=T`2/K;_%X`00'_J<9``#L.#R_`%6GA`"=
MIRD`#[D)`"/G`H```#>G&P`0YP``,`"!IX0`#.<!@```!J<;`!#G```P`(&G
M=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D`'CCH3_P_W&Y!``GP#```")U
MP.7___9FN00`8NPH_[$`?*>J``%!</%`0=#PL)4`8`"GA`![[+@`#P!\IP@`
M`+D$`!:Y!``KLET`$J<4__ZGA`!;IQD``.PV/+\`5:>$`+NG*0`/N0D`(^<"
M8```-Z<;`!#G```P`(&GA``,YP%@```&IQL`$.<``#``@:=T__CG,``'`"&Y
MA``SN2``,D$@(`&YXB`2IR0`EN-!/_#_<;D$`#;L%/__`-BY&``QE2\P`*=T
M`#Z2`#``&$&Y!``VIQK__[D8`#&5+S``IX3_]:?T`"]!MK`!I_3_0*<I``^G
M]/]QI[D``*?T_SB5`+`!IW0`&L`P```A^*<I``#`Y?__]>>Y!`!B["C_,@!\
ME0!@`*=T_XGLN``'`'R5+K``IX3_YL!@```ADZ=(``$:2J<8#__L0?\<(';C
M@/"H`"3`$```(=/C$/"@`"2G21``ISD``;D$`"?`4```(C3`Y?__]^>Y!`!-
MN00`-Z<I``'`Y?__]4[L)O^_`'Y8$/#(I2^``,`;``#P`.P2_[5@=KD$`">G
M.0`!P.7___>Z[";_JP!^N00`-\`@```AE\#E___\"[D$`"?`Y?__]CJG]/[A
MIRD`#Z?T_U-#(!`!I_3^E<#E___V[0<'!P<'!P<'!P<'![D$`!+C("```)#L
M*``@`'RSP0`/X_#_6/]QXP#PH``@&$*Y!``A0D#PI^,P$`$`D)4O\*=!$!`!
M&$.YXH`A[#;_]`!\L\T`\`?^N00`(0?^["@`5`!\E0`@`*>$`$^G&0``[$(\
MOP!5IX0`1*<Y``^Y"0`TYP,@```WIQL`$.<``#``@:>$``SG`2````:G&P`0
MYP``,`"!IW3_^.=```<`(;F$`$2Y(`!#03`P`;GB(!.G)``?XQ%/[_]QN0@`
M$KGI($'L(0!XH&65+Q``IW0`&^,0'___<:='__F5+R``IX0`#,`@```A#\#T
M___UKZ<Y``^G]/_*P"```""WP/3___6EN>D@0>PA`%:@9>,0'___<:='``2G
M]/_BE2\0`*=T__>YZ2!!XS`?__]Q[",`+B!E["@`*_]\XQ`?__]QIT<`*;D)
M`!*G21``[#$``@#9[#0`+B!EZ^_P<``DN00`,N/P_V#_<4%`$`&G61``P"``
M`$\<P.7___0)P"```$\6Z^_Q$``$!_ZG20`!I_3_UI4O$`"GA/_2N0D`$J=)
M$`#L,0`"`-GL-/_8P&6G*0``!_[L(?^X8&2G]/^1!P?K;_`P`"2R3P#0X_#_
M,/]QZ]T`(``-LD\`T<`0```_=]('\,C0*-(A\*80"L2H``!.6N.`H````J>$
M`VVG&`!%P&```"""06!@`;F4`!'L&``&`'[L%@50/7[`$```('6Y"0!AXW"`
M```"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```(&/`Y?__])+L)@`)`'Y!%G``
ME3T0`*>$`[5!L+`(XW"P```"IW3_Z..`H````J>$`S&G&`!%P&```"!+06!@
M`;F4`!'L&``&`'[L%@40/7[`$```(#ZY"0!AXW"````"IX0`(+D4`&:Y!`"X
MN00`1KD$`"?`,```("S`Y?__]%;L)@`)`'Y!%G``E3T0`*>$`ZA!L+`(XW"P
M```"IW3_Z..`H````J>$`O6G&`!%P&```"`306!@`;F4`!'L&``&`'[L%@30
M/7[`$```(`:Y"0!AXW"````"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```'_3`
MY?__]!KL)@`)`'Y!%G``E3T0`*>$`XY!L+`(XW"P```"IW3_Z..`H````J>$
M`KFG&`!%P&```!_<06!@`;F4`!'L&``&`'[L%@20/7[`$```'\^Y"0!AXW"`
M```"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```'[W`Y?__\][L)@`)`'Y!%G``
ME3T0`*>$`W1!L+`(XW"P```"IW3_Z..`H````J>$`GVG&`!!P&```!^D06!@
M`;F4`!'L&``&`'[L%@10/7[`$```'Y>Y"0!AXW"````"IX0`(+D4`&:Y!`"X
MN00`1KD$`"?`,```'X7`Y?__\Z+L)@`)`'Y!%G``E3T0`*>$`UI!L+`(XW"P
M```"IW3_Z..`H````J>$`D&G&`!!P&```!]P06!@`;F4`!'L&``&`'[L%@00
M/7[`$```'V.Y"0!AXW"````"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```'U'`
MY?__\V;L)@`)`'Y!%G``E3T0`*>$`T!!L+`(XW"P```"IW3_Z..`H````J>$
M`@6G&`!!P&```!\,06!@`;F4`!'L&``&`'[L%@/0/7[`$```'O^Y"0!AXW"`
M```"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```'NW`Y?__\RKL)@`)`'Y!%G``
ME3T0`*>$`R9!L+`(XW"P```"IW3_Z..`H````J>$`<FG&`!!P&```![^06!@
M`;F4`!'L&``&`'[L%@.0/7[`$```'O&Y"0!AXW"````"IX0`(+D4`&:Y!`"X
MN00`1KD$`"?`,```'M_`Y?__\N[L)@`)`'Y!%G``E3T0`*>$`PQ!L+`(XW"P
M```"IW3_Z..`H````J>$`8VG&`!!P&```!['06!@`;F4`!'L&``&`'[L%@.`
M/7[`$```'KJY"0!AXW"````"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```'JC`
MY?__\K+L)@`)`'Y!%G``E3T0`*>$`9%!L+`(XW"P```"IW3_Z..`H````J>$
M`5&G&`!!P&```!Z006!@`;F4`!'L&``&`'[L%@-`/7[`$```'H.Y"0!AXW"`
M```"IX0`(+D4`&:Y!`"XN00`1KD$`"?`,```'G'`Y?__\G;L)@`)`'Y!%G``
ME3T0`*>$`7=!L+`(XW"P```"IW3_Z..`H````J>$`16G&`!!P&```!XA06!@
M`;F4`!'L&``&`'[L%@,`/7[`$```'A2Y"0!AXY"````"IX0`(KD4`&:Y!`"X
MN00`>;D$`$:Y!``GP#```!X`P.7___(X["8`"0!^019P`)4]$`"GA`#U0;"P
M".-PL````J=T_^BG*`!!P!```!X@01`0`;F4`"+L*``&`'[L)@+#/7[`(```
M'A.Y"0`2[)@`'P!\N10`L;D$`$NY!``IP#```!X%P.7___(%["8`"0!^01N0
M`)4]$`"GA`)?08"`"..0@````J=T_^CC<*````*GA`"DIR@`0<`0```=\4$0
M$`&YE``B["@`!@!^["8"FSU^P"```!WDN0D`$N.0<````J>$`"*Y%`!AN00`
MM[D$`(FY!`!&N00`*,`P```=T,#E___QQ^PF``D`?D$6@`"5/1``IX0"*T&P
ML`CC@+````*G=/_HP!```!W#XR`0`0"401`0`>PH``8`?NPF__@]?L`@```=
MM;D)`!+LF``C`'RY%`"!N00`M[D$`*FY!`!(N00`*L`P```=H\#E___QD>PF
M``D`?D$8H`"5/1``IX0!T4&PL`CCH+````*G=/_HIR@`0<`0```=DT$0$`&Y
ME``B["@`!@!^["8",SU^P"```!V&N0D`$NR8`!\`?+D4`+&Y!`!+N00`*<`P
M```=>,#E___Q7NPF``D`?D$;D`"5/1``IX0!U$%P<`CCD'````*G=/_HP!``
M`!ULU0D0`/"WIW0!ET$P\,'`(```'2_`Y?__]WJG]`&-N0D`N.N[``,`"KD4
M`!OK$0`#``VY"``8XR`0"``$XR`0```D["C^Q`!\XR`0$``$01`0".,@$```
M).PF__@`?*?T_K:Y"0"XZ[L``P`*N10`&^L1``,`#;D(`!CC(!`(``3C(!``
M`"3L*/XJ`'SC(!`0``1!$!`(XR`0```D[";_^`!\I_3^'+D)`+CKNP`#``JY
M%``;ZQ$``P`-N0@`&.,@$`@`!.,@$```).PH_D0`?.,@$!``!$$0$`CC(!``
M`"3L)O_X`'RG]/XVN0D`N.N[``,`"KD4`!OK$0`#``VY"``8XR`0"``$XR`0
M```D["@`#@!\XR`0$``$01`0".,@$```).PF__@`?..`H````J=T^_K`$```
M',_5"1``\+>G=`#ZI_3_8[D)`+CKNP`#``JY%``;ZQ$``P`-N0@`&.,@$`@`
M!.,@$```).PH_!,`?.,@$!``!$$0$`CC(!```"3L)O_X`'RG]/P%N0D`N.N[
M``,`"KD4`!OK$0`#``VY"``8XR`0"``$XR`0```D["C\+0!\XR`0$``$01`0
M".,@$```).PF__@`?*?T_!^Y"0"XZ[L``P`*N10`&^L1``,`#;D(`!CC(!`(
M``3C(!```"3L*/Q'`'SC(!`0``1!$!`(XR`0```D[";_^`!\I_3\.;D)`+CK
MNP`#``JY%``;ZQ$``P`-N0@`&.,@$`@`!.,@$```).PH_&$`?.,@$!``!$$0
M$`CC(!```"3L)O_X`'RG]/Q3N0D`N.N[``,`"KD4`!OK$0`#``VY"``8XR`0
M"``$XR`0```D["C\>P!\XR`0$``$01`0".,@$```).PF__@`?*?T_&VY"0"X
MZ[L``P`*N10`&^L1``,`#;D(`!CC(!`(``3C(!```"3L*/R5`'SC(!`0``1!
M$!`(XR`0```D[";_^`!\I_3\A[D)`+CKNP`#``JY%``;ZQ$``P`-N0@`&.,@
M$`@`!.,@$```).PH_*\`?.,@$!``!$$0$`CC(!```"3L)O_X`'RG]/RA03B@
M`<`@```;=,#E___U[<`P```;SL`@```;B\#E___UY-4'\,C0**=T`&#K;_$`
M``0'_D$[D`'`(```&XW`Y?__]=.G]/VB03:``<`@```;$,#E___UR>-PH```
M`J>$_CSCD'````2G]/W.03N0`<`@```;;,#E___UMZ?T_\I#$&`!I_3\9T,0
M8`&G]/PG0Q!@`:?T^^=#$&`!I_3[IT,08`&G]/MG0Q!@`:?T^R=#$&`!I_3Z
MYT,08`&G]/JG0R`0`:?T_31#$&`!I_3\]T,08`&G]/RW0Q!@`:?T_'=#(!`!
MI_3]7,#E___P<D,@$`&G]/W$!P<'!P<'!P<'!P<'!P?$'0``20CL&``&_WZY
M%``A!_[KG_!(`"3$&```2,3C\/]@_W'CL!````*GA``XIQ@`0<"0```;"4&0
MD`&YE``1[!@`!@!^[!8`2#U^P!```!K\N0D`D>.@L````J>$`!^Y%`"9N00`
M2;D$`"K`,```&NS`Y?__[OL8$NPF``D`?D$IH`"5/2``IX0`%$&PL`CCH+``
M``*G=/_GIQ@``+D4`"'$'P``2+?KG_#H``0'_D$YH`'C*:`!`)"5`#``IX3_
M\,`G````,+D#`!+L$3^_`5FG]/_F0Q"0`:?T_Z\'!^OO\'``)./P_V#_<<#E
M___MKL#E___MB^PH``8`?.,@(```!.OO\1``!`?^!P<'!^MO\#``),08``!(
M1>/P_U#_<;D$`&+CL!````*GA``WIQ@`1,"0```:P4&0D`&YE``1[!@`!@!^
M[!8`E3U^P!```!JTN0D`D>.@L````J>$`!ZY%`"9N00`2;D$`"K`,```&J3`
MY?__[GKL)@`)`'Y!&:``E3T0`*>$`!1!L+`(XZ"P```"IW3_Z+D$`#;`(```
M&HSK;_#@``3`]/__])M!N:`!E0"P`*>$__&Y!``VN00`*\#E___MHNPH``<`
M?.MO\.``!`?^IQD``.PV/+\`5:>$`$2G*0`/N0D`(^<"8```-Z<;`!#G```P
M`(&GA``,YP%@```&IQL`$.<``#``@:=T__CG,``'`"&YA``SN2``,D$@(`&Y
MXB`2IR0`'^-!/_#_<:<I``#L.SR_`%6GA``=IQD`#[D)`!/G`;```#>G*P`0
MYP``,`"!IX0`$^<"L```!J?T__:G*0`/I_3_RD,0D`&G]/]BIQD`#Z?T__'G
M,``'`"&YA``SN2``,4$0$`&YXB`AIR3_\>,2/_#_<4$D$`+`Y?__[5'CL/"H
M`"3`$```&:?C$/"@`"2Y!`"RISD``<!0```:"Z=)___`Y?__[[RY!``[P"``
M`!GNZV_PX``$P/3___/]!P<'!^MO\#``)./@\`#X<>/P\`#_<>,`__@`(+DA
M`/ZG)/_XLD\`$+D$`/[C\/WH_W'CX/(8"''K$0`@``VGZ__X8(#@`+)/`!'C
M,/(("''C$/#0`"32!S``$"C`$```1V3$B```1RG2#_#8$`C2!_#H$!C2+_$(
M$"#2#_#P$%#2!_$`$&#C(/#(`"3C<(````*GA``[IR@`0<`0```9,4$0$`&Y
ME``B["@`!@!^["8'@#U^P"```!DDN0D`$N-@<````J>$`"*Y%`"1N00`M[D$
M`*:Y!`!)N00`*L`P```9$,#E___M3>PF``D`?D$9H`"5/1``IX0!!$&PL`CC
MH+````*G=/_HP.7__^PJP.7__^P'["@!30!\XZ`@```"IX0!1Z<9``#L.CR_
M`%6GA`$\IRD`#[D)`"/G`J```#>G&P`0YP``,`"!IX0`#.<!H```!J<;`!#G
M```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D`1?C(3_P_W'K(@`!
M``VG*P`!P.7__^QHXQ"@``"0L\$`@AAA[!@`'@!\L\T`N+D$`"NYA`!FP%``
M`!D<ITG__Z<Y``'`Y?__[L_C$*`!`)!!H*`!0;"P`AAA[!;_Z@!\07#Q$,"0
M```83T'0\3CCL(````*GA``[XR"0``"0N00`J1@2["@!]@!\0A#PQY4]\,>G
MA``+XR"@`0"00:"@`1@2[";_]`!\&ZGC8+````*GA``=N10`JKD$`$JY!``Y
MN00`)L#E___LG^PF``D`?D$:8`"5/1``IX0!E4&PL`CC8+````*G=/_IIWL`
M"..0?_C_`J=T_[VGJ```09#Q.+D4`!KK$0`#``WCL?#8``*GA``ME0"P`*>$
M`"FY!`!)N00`.Z<I``'`Y?__[)WL)@`2`'Y8$/%0IRA``,`;``#P`.P2`/N`
M=J4OH`#L$@#V@':GJ@`!N10`&NL1``,`#>.Q\-@``J=T_]>G:0``IQD``.PV
M/+\`5:=T`/VG*0`/I_0!!T'9H`&5`-``IX3_`:<H`$3`$```&%Y!$!`!N90`
M(NPH``8`?NPF`@0]?L`@```84;D)`!*Y%`"QN00`2[D$`";`,```&$;`Y?__
M[!SL)@`)`'Y!&V``E3T0`*>$`4U!<'`(XV!P```"IW3_Z+D$`#W`(```&"[`
MY?__\D#C$/#0``3C(/(("''5!R``$"BG=`&.[8#R$`AEN00`+>MO\D@(!,#T
M___L7J<I``^G]/[2I[@``+D4`!OK$0`#``WCD?#P``*GA`!2X]"````$['L`
M`0#8[-@`/@!\XS"0``"0N00`&1@C[#@!7@!\0B#PQY4]\,>GA``+XS`0`0"0
M01`0`1@C[#;_]`!\&QGC8-````*GA``?N10`H;D$`+VY!`!*N00`.;D$`";`
MY?__ZZKL)@`)`'Y!&F``E3T0`*>$`"-!L+`(XV"P```"IW3_Z;D4`!>G>@`!
MZQ$``P`-XY'P\``"IW3_N*<I``W`H```%[C`Y?__ZO:G:`!3L\$`@J?T_I-!
M*F`!&+>5`"``IX3_X<#E___KYKD$`*+L*/^,`'RG&0``[#H\OP!5IX3_?J?T
M_D*Y!``KISD``L#E___M0>PF_P8`?KD$`"O`Y?__Z\FGJ@`!N00`8NPH_M$`
M?*<9``#L-CR_`%6GA/\'IRD`#[D)`"/G`F```#>G&P`0YP``,`"!IX0`#.<!
M8```!J<;`!#G```P`(&G=/_XYS``!P`AN80`,[D@`#)!("`!N>(@$J<D_N+C
ML3_P_W&SS0`8IRD``.PQ/+\`5:>$`R6G&0`/N0D`$[/-`#CG`3```#>G*P`0
MYP``,`"!IX0`Y+/-`#CG`C````:G]/_T0;I@`94`L`"GA/YPN00`3;D$`#NG
M*0`!P.7__^LD[";^90!^6!#Q4*<H0`#`&P``\`#L$@`(@':E+Z``[!+^5F!V
MN00`*Z<Y``+`Y?__[+OL)OY,`'ZY!``KP.7__^M#N00`8NPH_DD`?*?T_WRG
MJ```I_3^&T&K8`&5`*``IX3^N+D$`#VY!``JP.7__^H+[";^MP!\[#T\OP!5
MIX0`2Z<9``^Y"0`3YP'0```WIRL`$.<``#``@:>$``SG`M````:G*P`0YP``
M,`"!IW3_^.<P``<`(;F$`#.Y(``Q01`0`;GB("&G)``FXT(_\/]QIRD``.PZ
M/+\`5:>$`%:G&0`/N0D`$^<!H```-Z<K`!#G```P`(&GA``2YP*@```&I_3_
M]J<8``"G]/ZSP.7__^N:IQD`#Z?T_\/G,``'`"&YA``SN2``,4$0$`&YXB`A
MIR0`*^,2/_#_<4$D$`+`Y?__Z<'CH/"H`"3`$```%A?C$/"@`"2Y!`"RN00`
M;<!0```6>Z=)__^G.0`!P.7__^PJN00`.\`@```67,#E___P;J?T_BZG&0`/
MI_3_N$,@$`&G]/WSYS``!P`AN80`,[D@`#%!$!`!N>(@(:<D`B;C$C_P_W$:
ML:>Z!`2Y%`"[N00`*\#E___I?F"`\+#`$```%D?C$/"H`"2SP0""P!```!7.
MXQ#PH``DISD``<!0```6,J=)___`Y?__Z^2SS0`HISD!P,#E___JW>PF``O_
M?L#E___JIU@0(`#L%@'/$7ZSS0`X04#Q.*<I``'`Y?__Z@D8DNPF``T`?E@0
M\5"G*$``P!L``/``[!(`+X!VXR#PR``$Q!@``$.)XU`@```$L\T`:.,@$```
M!,!````6&:<Y``&GV0``P.7__^L#XQ#PT``$XR#R"`AQU0<@`!`HIW3_/;D$
M`"WM@/(0"&7K;_)("`0'_EB@\53`Y?__Z(KLHO_/8'98$/%0IR@!P,`;```!
M_^P2_\5@=KD$`"O`Y?__Z/CCL(````*Y!`#2IX0`-Z<H`$'`$```%:]!$!`!
MN90`(NPH``8`?NPF`8(]?L`@```5HKD)`!+CH+````*GA``>N10`<;D$`$>Y
M!``JP#```!62P.7__^E<["8`"0!^01>@`)4]$`"GA`$=0;"P"..@L````J=T
M_^CC$/#(``3CH!````2G&0``[#H\OP!5IX0!)Z<I``^Y"0`CYP*@```WIQL`
M$.<``#``@:>$``SG`:````:G&P`0YP``,`"!IW3_^.<P``<`(;F$`#.Y(``R
M02`@`;GB(!*G)`$"XQ$_\/]Q[!P`(`-^N10`(<`P```5F.,BK_S_<:<(``"R
M70`RIQ3__J=T``_L&`)9!'ZG&O_[N10`$4$1H`"5+Q``IX0"3L0=``!"R.P8
M`5S_?NP8`9D`?L`P```5"\`@```4UL#E___O(<#E___IXL`0```5RN,@\*@`
M).,0\+``)+/-`&C`$```%*'C$/"@`"2Y!``MP%```!5CITG__Z<Y``'`Y?__
MZK6G]``RP.7__^F`6!`@`*<>`!&G=``SP.7__^FWIYH``;D4`!GC$/"P`"3C
M(/"H`"3`$```%96SS0!HXQ#PN``DP!```!1OXQ#PH``DN00`+<!0```5.*=)
M__^G.0`!P.7__^J#N00`+:<Y`<#`Y?__Z7SL*/_)_WZSS0`HP.7__^I$N00`
M/<`@```4/\#E___NN..P@````J>$`#>G*`!$P!```!2901`0`;F4`"+L*``&
M`'[L)@)#/7[`(```%(RY"0`2XZ"P```"IX0`'KD4`)&Y!`!)N00`*L`P```4
M?,#E___H4NPF``D`?D$9H`"5/1``IX0`7$&PL`CCH+````*G=/_HN00`/<`@
M```49,#E___N=J?T_H?C$/#(``1!)Z`!X[`0```$P.7__^B=N00`,KD$`"O`
MY?__\-*Y!`"B["C^V`!\IQD``.PZ/+\`5:=T_MVG*0`/I_3^Y[D4`!'C$/"@
M`"3$*```0=+C$/#(``2SS0!HXU`0```$XR`@```$P$```!1!ISD``:?9``#`
MY?__Z4FG]/Y&IQD`#Z?T_.M#(!`!I_3^=4&YH`&5`+``IX3_J;D$`#VY!``K
MP.7__^<R[";^+P!\[#T\OP!5IX0!?Z<9``^Y"0`3YP'0```WIRL`$.<``#``
M@:>$``SG`M````:G*P`0YP``,`"!IW3_^.<P``<`(;F$`#.Y(``Q01`0`;GB
M("&G)`%:XT(_\/]QIRD``.P[/+\`5:>$`;^G&0`/N0D`$^<!L```-Z<K`!#G
M```P`(&GA`%[YP*P```&I_3_]N.P@````J>$`#>G*`!!P!```!-\01`0`;F4
M`"+L*``&`'[L)@&A/7[`(```$V^Y"0`2XV"P```"IX0`'KD4`'&Y!`!'N00`
M)L`P```37\#E___G;NPF``D`?D$78`"5/1``IX0`JT&PL`CC8+````*G=/_H
MP!```$$OY4P0````N00`*J<Y``#`Y?__Z2&Y!`"R&*+L*/Y@`'ZG20`"ISG_
M[L#E___FU$&0\@BY!``KN00`.:=)``;`Y?__Z-F5`/((IW0`!I5#\@FGA`#:
MN00`*Z=)``"G.0``N10`JL#E___FML#E```0O[D$`+*G]``+N00`.;D$`"NY
M%`!$P.4``!#JI4^``+D$`#FY!``JP.7__^BMN00`0NPB_^P`?KD$`"I!H/'+
MN00`FL#E___F/[D$`#NY!``JP.4``!%D0:#QWZ>Y`!3C8)```)"Y!``JIYL`
M`:>K``+`4```$QZG2?__ISD``<#E___HT:>W_^W`$```$\>SS0!HXQ#PL``D
MD@#R!T$0\=_C$/"H`"2Y!``MP!```!*8XQ#PH``DP%```!-4ITG__Z<Y``'`
MY?__Z*ZG]/XUXQ=@`0"4[!C_6P!^[!C_6#!^P!```$"$Y4P0```!I_3]O^,0
M\,@`!.,@$`@``J>$_:ZG.0``[$(\OP!5IX0`/:<9``^Y"0`4YP$@```WISL`
M$.<``#``@:>$``SG`R````:G.P`0YP``,`"!IW3_^.=```<`(;F$`$2Y(`!!
M01`0`;GB(#&G)``8XQ-/\/]Q[!S]?0-]XS$O_/]QIP@``,`0```2];)=`!.G
M%/_^N>*`HJ?T_6RG&0`/I_3_T:<9``^G]/Z/E4'R"J=T_R:50_(+IW3_(I5(
M\@RG=/\>E47R#:=T_QJG20`"ISG_QKD$`"O`Y?__Y="Y!``KN00`.:=)`"G`
MY?__Y]?`$```$Q^SS0!HXY#PJ``DXQ#PL``DN00`+:?T_UQ#(!`!I_3]M.<P
M``<`(;F$`#.Y(``Q01`0`;GB("&G)``KXQ(_\/]Q0200`L#E___E?^.P\*@`
M),`0```1U>,0\*``)+D$`+*Y!`!MP%```!(YITG__Z<Y``'`Y?__Y^BY!``[
MP"```!(:P.7__^PLI_3\/:<9``^G]/Y/0R`0`:?T^'=#(!`!I_3^5@<'!P<'
M!^MO\#``),2(```_>>/P_V#_<>,@@```%L#E___G4+D$`++C((```!;`Y?__
MYTC2`""YL+C$>```/U[CL'````*GA``WIQ@`0<"0```1F$&0D`&YE``1[!@`
M!@!^[!8!A#U^P!```!&+N0D`D>.@L````J>$`!ZY%`"9N00`2;D$`"K`,```
M$7O`Y?__Y9CL)@`)`'Y!&:``E3T0`*>$`2M!L+`(XZ"P```"IW3_Z,#E___P
ML>,@@```%L#E___F_Z=9``.G20`!P#```!(?P.7__^5%N00`LNPH`!\`?.,@
M@```%L#E___FZN,0L!``!,!````2#.,P$```!,#E___E/N,0L!``!.,0$```
M!)%`$`VG=`$8XR"````6P.7__^;.IUD``Z=)``'`,```$?+`Y?__Y12Y!`!B
M["@`4@!\X[!P```"IX0`-Z<8`$'`D```$/I!D)`!N90`$>P8``8`?NP6`1\]
M?L`0```0[;D)`)'CH+````*GA``>N10`F;D$`$FY!``JP#```!#=P.7__^45
M["8`"0!^01F@`)4]$`"GA`"T0;"P"..@L````J=T_^CC((```!;`Y?__YG_C
M(&`0``3$&```/PWC("````3C,!````3`Y?__ZFSC((```!;`Y?__YFJY!`"R
MXR"````6P.7__^9BITD``<`P```1B<#E___CVL!````1CKD$`#*Y!``KP.7_
M_^2PXR"````6P.7__^9*D@`@N>.P<````J>$`#>G&`!!P)```!!^09"0`;F4
M`!'L&``&`'[L%@"./7[`$```$'&Y"0"1XZ"P```"IX0`'KD4`)FY!`!)N00`
M*L`P```08<#E___DGNPF``D`?D$9H`"5/1``IX0`4D&PL`CCH+````*G=/_H
MQ"@``#Z?P!```#Z@Y4@0````P.7___;&Q"L``#Z7N00`LNPH`%@`?+D$`"NG
M.0'`P.7__^5C["@`"1%^[!(``0#8[!(`3@%_ZV_PT``$!_Y!&:`!E3$0`*=T
M_MJ5`!`!IX3^V:?T_M3C((```!9!N:`!P.7__^72XQ!@$``$N00`2^,P$```
M!,#E___D)Z?T_U=!N:`!Q+L``#Y8I_3_QN,@@```%L#E___EN.,0L!``!.,P
M$```!,#E___E3Z?T_MM#$)`!I_3^<T,0D`&G]/]IP"```!#<P.7__^6OQ!@`
M`#XPN00`4N,P$```!+D$`$O`(```$-W`Y?__Y9]#$)`!I_3^V`<'!P<'!P<'
MZV_P,``DLD\`L./P_KC_<>N[`"``#;)/`+&Y!`!BT@?Q0+`H["@`6`!\E0`@
M`*>$`%.G&0``[#(\OP!5IX0`2*<I``^Y"0`CYP)@```WIQL`$.<``#``@:>$
M``SG`6````:G&P`0YP``,`"!IW3_^.<P``<`(;F$`#.Y(``R02`@`;GB(!*G
M)``CXQ$_[_]QN0@`%KGI8"'L80&#H&65+Q``IW0!.>,0'___<:<G__F5+Q``
MIX0`$,`@```/=<#E___D%;D$`!*G]``.IRD`#Z?T_\;`(```#QG`Y?__Y`>Y
M!``2XR`0``"0N00`H1@R["@`$@!\0C#PK^,@$`$`D)4O\*]!$!`!&#*YXH"A
M[";_]`!\Q!T``#U.[!@`%O]^[!@`"@!^[&@`!P!\E0!@`*=T`%#5!_%`L"BG
M=`$WZV_Q>``$!_[$&```//WCD!````*GA``WIR@`0<`0```/14$0$`&YE``B
M["@`!@!^["8!(#U^P"````\XN0D`$N.`D````J>$`!ZY%`!QN00`1[D$`"C`
M,```#RC`Y?__XS?L)@`)`'Y!%X``E3T0`*>$`(A!D)`(XX"0```"IW3_Z,`0
M```\^.5,$````*?T_[2Y!``JITD`!,`P```/5L#E___C%>PF_Z@`?KD$`";`
MY?__Y1VY!`!R["C_G@!\[)8\OP!50=#PL*>I``^Y!``GP.7__^.<["@`90!\
M08`@$Y4N(!.G=``&E0"``:>$__"5+B`3IX0`8J<9``#LF`!H`'RYZ9`ZYP-@
M```WIQL`$.<``#``@:>$``SG`6````:G&P`0YP``,`"!IW3_^.=```<`(;F$
M`$2Y(`!#03`P`;GB(!.G)`!$XT%/\/]QISD``.P8/+\`5:>$`(^YZ1`:YP$@
M$P`WISL`$.<``#``@:>$`(?G`R`3``:G]/_VXQ>``0"4[!C_?@!^[!C_>S!^
MP!```#QPY4P0```!I_3_);D$`"?`Y?__X<*Y!``FP.7__^(MI_3_()4N@`&G
M=/^>E0"``J>$_X2G]/^8ISD`#Z?T_Z6YZ6`A[&$`0Z!EXQ`?__]QIR<`!*?T
M_L25+Q``IW3_][GI8"'C,!___W'L8P`F(&7L:``C_WSC$!___W&G)P`AN0D`
M%J<Y$`#L(0`"`-GL(P!^(&5!0!`!N00`-J=9$`#`(```/&K`Y?__X5?`$```
M/&2G]/ZOIRD``:?T_]Z5+Q``IX3_VJ?T_]WL8?_+8&2G]/Z&P.7__^-@0R`0
M`:?T_M>G&0`/I_3_?>=0``<`(;F$`%6Y(`!101`0`;GB(#&G)/_QXR-?\/]Q
M&B2G*@`"N10`(L#E___A@..`\*``)*=)__^Y!`""ISD``<!0```-F,#E___C
M\;D$`$VY!``XIRD``<#E___A6.PH``W_?E@0\,BG*$``P!L``/``[!(`#X!V
MN00`*,#E___C5KD$`"C`Y?__XZ&G]/[@N00`*,#E___F5J?T__3C$````)"G
M]``!!P<'!P<'!P?K;_`P`"2R3P"PX_#\T/]QZ[L`(``-LD\`L4$0\*C2!_,H
ML"BY!`!!0:`@.*=9``CC,*````2G2P`0ZP,`(``,XP!/\/\DP#H`````XS!/
M^/\D0:"@"*=7_^VG20!`XS`0:``$IQL`".,P$#@`@N,P$`@`@N,P'_C_@NQ3
M(+\A6>Q3(#X!5N-0$'@`)*='_^GC0"````3C4"`0``3CH"`(``3C`"`8``3C
MT/"P``3C`/"@`"3C,/"H``3K:@`"``SL:@`A'E;L=B"_`%6YYW`5N8``%+F"
M`!7"VEJ">9FY"`#0N0@`T;GG`!6Y@``:N8(`$.R4(+\E6<(Z6H)YF>R4(#H%
M5N,P("``"+D(`).Y"`"1XQ#PN``$[(D@OP!5PAI:@GF9L\$``;/-``#L&3N_
M)5GL&``Z!5:Y"``=N>A0T.LT``(`#.PT`"$>5KF"`&.Y@`!HN8(`9[D(`&WC
MT/#```3C`/#(``3"VEJ">9FY"`#7[)$@OP!5ZW@``@`,[!$[OR59['@`(1Y6
M[!D`.@56N0@`%NQC(+\`5;F"`#>Y@``YN8(`-KD(`#WCT/#0``3""EJ">9FY
M"``&[($@OP!5[&<@OP!5PMI:@GF9[!$[OR59N0@`UNP8`#H%5KD(`!/K.0`"
M``SL.0`A'E:Y@@!SN8``>+F"`':Y"`!PXP#PV``$[)$@OP!5[&,@OP!5[!$[
MOR59[!D`.@56N0@`%^MX``(`#.QX`"$>5KF"`#>Y@``YN8(`-KD(`#WCT/#@
M``3""EJ">9FY"``&[($@OP!5[&<@OP!5PMI:@GF9[!$[OR59N0@`UNP8`#H%
M5KD(`!/K.0`"``SL.0`A'E:Y@@!SN8``>+F"`':Y"`!PXP#PZ``$[)$@OP!5
M[&,@OP!5[!$[OR59[!D`.@56N0@`%^MX``(`#.QX`"$>5KF"`#>Y@``YN8(`
M-KD(`#WCT/#P``3""EJ">9FY"``&[($@OP!5[&<@OP!5PMI:@GF9[!$[OR59
MN0@`UNP8`#H%5KD(`!/K.0`"``SL.0`A'E:Y@@!SN8``>+F"`':Y"`!PXP#P
M^``$[)$@OP!5[&,@OP!5[!$[OR59[!D`.@56N0@`%^MX``(`#.QX`"$>5KF"
M`#>Y@``YN8(`-KD(`#WCT/$```3""EJ">9FY"``&[($@OP!5[&<@OP!5PMI:
M@GF9[!$[OR59N0@`UNP8`#H%5KD(`!/K.0`"``SL.0`A'E:Y@@!SN8``>+F"
M`':Y"`!PXP#Q"``$[)$@OP!5[&,@OP!5[!$[OR59[!D`.@56N0@`%^MX``(`
M#.QX`"$>5KF"`#>Y@``YN8(`-KD(`#WCT/$0``3""EJ">9FY"``&[($@OP!5
M[&<@OP!5PMI:@GF9[!$[OR59N0@`UNP8`#H%5KD(`!/K.0`"``SL.0`A'E:Y
M@@!SN8``>+F"`':Y"`!PXP#Q&``$[)$@OP!5[&,@OP!5[!$[OR59[!D`.@56
MN0@`%^MX``(`#.QX`"$>5KF"`#>Y@``YN8(`-KD(`#WCT/$@``3""EJ">9FY
M"``&[($@OP!5[&<@OP!5PMI:@GF9[!$[OR59N0@`UNP8`#H%5KD(`!/K.0`"
M``SL.0`A'E:Y@@!SN8``>+F"`':Y"`!PXP#Q*``$[)$@OP!5[&,@OP!5[!$[
MOR59[!D`.@56N0@`%^MX``(`#.QX`"$>5KF"`#>Y@``YN8(`-KD(`#WCT/$P
M``3L@2"_`%7""EJ">9GL$3N_)5FY"``&[!@`.@56[&<@OP!5N0@`$^LY``(`
M#.PY`"$>5KF"`'.Y@`!XN8(`=KD(`'#LD2"_`%7"VEJ">9GL$3N_)5FY"`#6
M[!D`.@56ZV@``@`,N0@`%^QH`"$>5NQS(+\`5>R!(+\`5;F"`#;L$3N_)5FY
M@``Y[!@`.@56L\$`(;GG<!/C,/$X``2Y"``=PCI:@GF9N0@`-[/!``.SS0`R
MZWD``@`,N0@`$^QY`"$>5NPV(+\`5;F"`&>YY("6XV#Q0``$L\T``,)J6H)Y
MF>S1.[\E6>S1(#H%5KF"`).YZ#`VN0@`D+/!``.Y"`"=L\T``.S7(+\`5>MH
M``(`#.QH`"$>5KF"`';`&@````"YY!`WXW#Q2``$N8(`/>R).[\E6;D(`##C
M`/%0``3LB2`Z!5;">F[9ZZ&Y"``XN0@`?>O1``(`#+D$`(WL@0`A'E;L$SN_
M)5GL$R`Z!5:YYX#6P@INV>NAN8(`V;D:``:Y&@!]N0@`<>P7.[\E6>P7(#H%
M5NS9(K\^6;/!`"'LV0(A'E;C$/%8``2YY]!HN00`D+F"`&.SS0`"N1H`ENQC
M(K\^6>QC`B$>5KGG8#VY@@`WN0@`D,(:;MGKH;D:`!CLB3N_)5FY&@`3[(D@
M.@56L\$`"+/-`##C@/%@``2Y"``3[#$[OR59[#$@.@56L\$``^,P\6@`!+/-
M``#"BF[9ZZ'".F[9ZZ&Y&@"-N1H`-NS7(K\^6>S7`B$>5KGGT':Y@@!YN1H`
MA[D(`(#L:#N_)5GL:"`Z!5;L>2*_/EFSP0`&['D"(1Y6[&$BOSY9N>=PG>QA
M`B$>5KF"`)&SS0`0N1H`.>.0\7``!+D(`#'"FF[9ZZ&YYV`7N8(`&+D:`)VY
M&@"1XQ#Q>``$[`,[OR59N00`V<(:;MGKH;D$`)"Y&@`7[),@.@56['@BOSY9
MN0@`G>QX`B$>5NS9.[\E6>.`\8``!.S9(#H%5K/!``VSS0``N>=PUL**;MGK
MH;F"`-.Y&@"&N1H`'>QC(K\^6;D(`!#L8P(A'E;L,3N_)5GL,2`Z!5:SP0`#
MXS#QB``$L\T``+GG8->Y@@#9PCINV>NAN1H`C;D:`#>Y"`"`['DBOSY9[-@[
MOR59['D"(1Y6[-@@.@56XY#QD``$L\$`#;/-``"YYW#6PIINV>NAN8(`T;D:
M`):Y&@`][&$BOSY9N0@`,.QA`B$>5NP3.[\E6>P3(#H%5K/!``'C$/&8``2S
MS0``N>=@U[F"`-C"&F[9ZZ&Y&@"=N1H`%[D(`)#L>"*_/EGLV3N_)5GL>`(A
M'E;LV2`Z!5;C@/&@``2SP0`-L\T``+GG<-;"BF[9ZZ&Y@@#3N1H`AKD:`!WL
M8R*_/EFY"``0[&,"(1Y6[#$[OR59[#$@.@56L\$``[/-``"YYV#7XS#QJ``$
MN8(`V;D:`(VY"`"`[-@[OR59[-@@.@56L\$`#;/-``#".F[9ZZ&Y&@`W['DB
MOSY9['D"(1Y6XY#QL``$N>=PUKF"`-&Y&@`][-$BOSY9N0@`,.S1`B$>5NP3
M.[\E6>P3(#H%5K/!``&SS0``PIINV>NAN1H`EKGGT&>Y@@!HN1H`EKD(`)#L
M:3N_)5GL:2`Z!5;C$/&X``2SP0`&XV#QP``$L\T``,(:;MGKH<)J;MGKH;D:
M`!>Y&@!M['@BOSY9['@"(1Y6N>=PC>S3(K\^6;F"`(/LTP(A'E:Y&@`8N0@`
M$.PQ.[\E6>PQ(#H%5K/!``/C,/'(``2SS0``N>?0A\(Z;MGKH;F"`(FY&@`W
MN1H`:+D(`&#L=CN_)5GL=B`Z!5:SP0`'L\T``.R)(K\^6>-P\=``!.R)`B$>
M5KGG@)VY@@"1N1H`.>R1(K\^6;D(`##LD0(A'E;L$SN_)5GL$R`Z!5;">F[9
MZZ&SP0`!N1H`?>,0\=@`!+GGD-BY@@#6L\T``+D:`'WLUB*_/EGLU@(A'E:Y
MY]!IN8(`8\(:;MGKH;D:`!BY&@`6[&,BOSY9[&,"(1Y6XS#QX``$N0@`<.R'
M(+\`5>P'.[\E6>P(`#H%5L(Z;MGKH;D(`!"Y&@`YN>=@#;F"``>Y&@`PN00`
MD^,P\>@`!.QQ(+\`5>P1.[\E6>P7`#H%5L(ZCQN\W+D(`)&Y&@`]ZQ@``@`,
ML\$``^P8`"$>5K/-``#LT2"_`%6YY-"&N>80-KF``#>Y@0`X[(D@OP!5[)D[
MOR59[)@`.@56N0@`,.,`\?``!+D(`#GKEP`"``SLEP`A'E:YY-!YN8$`&;F`
M`!BY@0`7XW#Q^``$P@J/&[S<N1H`!L)ZCQN\W+D(`!"YZ-`'[&,@OP!5[#,[
MOR59[#8`.@56N0@`,>L8``(`#.P8`"$>5NS1(+\`5;GF$'FYY-")N8``=KF!
M`'BY"`!PXP#R```$[(,@OP!5P@J/&[S<N1H`">N6``(`#.R6`"$>5KGDT&FY
M@0`9N8``&+F!`!;C8/((``2Y"``0PFJ/&[S<N>C0!NPS.[\E6>PX`#H%5KD(
M`#?L<R"_`%7L,SN_)5GL-P`Z!5:Y"``QZQ@``@`,[!@`(1Y6[-$@OP!5N>80
M:;GDT(FY@`!GN8$`:+D(`&#C`/(0``3L@R"_`%7""H\;O-RY&@`)ZY<``@`,
M[)<`(1Y6N>30>;F!`!FY@``8N8$`%^-P\A@`!+D(`!#">H\;O-SL,SN_)5FY
MZ-`'[#@`.@56N0@`-NQC(+\`5>PS.[\E6>PV`#H%5KD(`#'K&``"``SL&``A
M'E;LT2"_`%6YYA")N>30>;F``(:Y@0"'N0@`@.QS(+\`5>,`\B``!.PS.[\E
M6>PW`#H%5KD(`#CKA@`"``SLA@`A'E:YY-!HN8$`&+F``!>Y@0`6XV#R*``$
MP@J/&[S<N1H`"<)JCQN\W+D(`!"YZ-`&[),@OP!5[#,[OR59[#D`.@56N0@`
M,>L7``(`#.P7`"$>5NS1(+\`5;GF$&BYY-!XN8``:;F!`&>Y"`!@XP#R,``$
M[',@OP!5P@J/&[S<N1H`".N)``(`#.R)`"$>5KF!`!BY@``7N>30F+F!`)'C
M$/(X``2Y"`"0PAJ/&[S<N0@`';/!``&SS0``[#,[OR59[#<`.@56N0@`-NQC
M(+\`5>PS.[\E6>PV`#H%5NL7``(`#+D(`)/L%P`A'E;LT2"_`%6YYA`XN>30
M>+F``#:Y@0`WN0@`,.,`\D``!.QY(+\`5<(*CQN\W.R9.[\E6>R7`#H%5K/!
M``"Y"``YZY8``@`,[)8`(1Y6N>30";/!`""SS0``N8$`&;D:``BSP0``L\T`
M`KF``!>Y@0`0L\T``.QC(+\`5>.`\D@`!+D(`!#"BH\;O-RYZ-`([#,[OR59
M[#8`.@56N0@`,>L7``(`#.P7`"$>5NS1(+\`5;GF$'FYY-")N8``=KF!`'BY
M"`!PXP#R4``$[(,@OP!5[#,[OR59[#@`.@56P@J/&[S<N1H`";GH,)?K-@`"
M``SL-@`A'E:YY-!CN8$`$[F``!BY@0`6XV#R6``$N0@`$,)JCQN\W+GHT`;L
M>2"_`%7LF3N_)5GLEP`Z!5:Y"`"1ZQ@``@`,[!@`(1Y6[-$@OP!5N>808[GD
MT(.Y@`!GN8$`:+D(`&#C`/)@``3LB2"_`%7LF3N_)5GLF``Z!5;""H\;O-RY
M&@`#N>B0-NN7``(`#.R7`"$>5KGDT'FY@0`9N8``&+F!`!?C</)H``2Y"``0
MPGJ/&[S<N>C0!^QC(+\`5>PS.[\E6>PV`#H%5KD(`#'K&``"``SL&``A'E;L
M<2"_`%6YYA#9N>1PB;F``-:Y@0#8N0@`T.,`\G``!.R#(+\`5>PS.[\E6>PX
M`#H%5KD(`#W""H\;O-SLTR"_`%6Y&@`)ZY8``@`,[)8`(1Y6[&,[OR59N>1P
M.;F!`!FY@``8N8$`$^,P\G@`!.QM`#H%5L(ZCQN\W+/!``.YZ``QL\T`$+D(
M`#:Y"``7L\$``;/-``#K>``"``SL>``A'E;L9R"_`%6YYG`9N>1@B;F``!VY
M@0`8N0@`$.R#.[\E6>R#(#H%5KD(`('C$/*```3`.@````#K#0`"``S"&H\;
MO-RY&@`9N00`D.R=`"$>5KF!`'FY@`!SL\$``;GD8!FSS0``N8$`%^-P\H@`
M!+D(`!#">LIBP=;LV#N_)5FYZ&`'[-@@.@56N0@`'>QA.[\E6>QA(#H%5K/!
M`$;C8/*0``3K<P`"``SL<P`A'E:Y!``PL\T`!+GG<-G":LIBP=:Y&@!IXY#R
MF``$N8(`V+/!``:Y&@`]N0@`,+/-``#"FLIBP=:Y&@"7[&@BOSY9L\$`2>QH
M`B$>5NR#.[\E6;GG8-?L@R`Z!5:Y@@#1N1H`#;D(`(#LF#N_)5GLF"`Z!5;L
M<2*_/EFSP0`IXY#RH``$['$"(1Y6L\T``K/-`!2YYW#6PIK*8L'6N8(`T[D:
M`):Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ(#H%5K/!``/C,/*H``2S
MS0``N>=@U[F"`-C".LIBP=:Y&@"=N1H`-[D(`)#L>"*_/EGLV3N_)5GL>`(A
M'E;LV2`Z!5;C@/*P``2SP0`-L\T``+GG<-;"BLIBP=:Y@@#1N1H`AKD:`#WL
M82*_/EFY"``P[&$"(1Y6[!,[OR59[!,@.@56L\$``>,0\K@`!+/-``"YYV#7
MN8(`V<(:RF+!UKD:`(VY&@`7N0@`@.QY(K\^6>S8.[\E6>QY`B$>5NS8(#H%
M5N.0\L``!+/!``VSS0``N>=PUL*:RF+!UKF"`-.Y&@"6N1H`'>QC(K\^6;D(
M`!#L8P(A'E;L,3N_)5GL,2`Z!5:SP0`#XS#RR``$L\T``+GG8->Y@@#8PCK*
M8L'6N1H`G;D:`#>Y"`"0['@BOSY9[-D[OR59['@"(1Y6[-D@.@56XX#RT``$
ML\$`#;/-``"YYW#6PHK*8L'6N8(`T;D:`(:Y&@`][&$BOSY9N0@`,.QA`B$>
M5NP3.[\E6>P3(#H%5K/!``'C$/+8``2SS0``N>=@U[F"`-G"&LIBP=:Y&@"-
MN1H`%[D(`(#L>2*_/EGLV#N_)5GL>0(A'E;LV"`Z!5;CD/+@``2SP0`-L\T`
M`+GG<-;"FLIBP=:Y@@#3N1H`EKD:`!WL8R*_/EFY"``0[&,"(1Y6[#$[OR59
M[#$@.@56L\$``^,P\N@`!+/-``"YYV#7N8(`V,(ZRF+!UKD:`)VY&@`WN0@`
MD.QX(K\^6>S9.[\E6>QX`B$>5NS9(#H%5N.`\O``!+/!``VSS0``N>=PUL**
MRF+!UKF"`-&Y&@"&N1H`/>QA(K\^6;D(`##L80(A'E;L$SN_)5GL$R`Z!5:S
MP0`!XQ#R^``$L\T``+GG8->Y@@#9PAK*8L'6N1H`C;D:`!>Y"`"`['DBOSY9
M[-@[OR59['D"(1Y6[-@@.@56XY#S```$L\$`#;/-``"YYW#6PIK*8L'6N8(`
MT[D:`):Y&@`=[&,BOSY9N0@`$.QC`B$>5NPQ.[\E6>PQ(#H%5K/!``/C,/,(
M``2SS0``N>=@U\(ZRF+!UKF"`-BY&@`WN1H`G;D(`)#L>3N_)5GL>2`Z!5:S
MP0`'XW#S$``$L\T``.S8(K\^6<)ZRF+!UNS8`B$>5KD:`':YY]"&[&$BOSY9
MN8(`@>QA`B$>5KD:`#BY"``P[!,[OR59[!,@.@56N>=@C;/!``&Y@@")XQ#S
M&``$N1H`>.R)(K\^6>R)`B$>5KGG@):Y@@"3L\T``,(:RF+!UKD:`!VY&@`9
M[),BOSY9[),"(1Y6XS#S(``$N0@`<,(ZRF+!UNS7(+\`5>P'.[\E6>P-`#H%
M5KD(`$.Y"``0N1H`1NPQ(+\`5;GGD`BY@@!P[!$[OR59N1H`1^P3`#H%5KD(
M`!2Y"``ZP#H`````XS`@"``DP!H`````XQ`@```DXS#PH``$N00`&.,0("``
M",`:`````.,0("``)+D(`#GK'0`"``S`.@````#C,"`8`"3L'0`A'E:Y"``5
MP!H`````XQ`@$``DU0?S*+`HIW0`!NMO\V``!`?^P.7__]><!P<'!P<'!P<'
M!^OO\'``)*<I`(#C\/]@_W'`Y?__U<S`,6=%(P'C,"```"3`/^_-JXGC,"`(
M`"3`/YBZW/[C,"`0`"3`,1`R5';C,"`8`"3E2"`H``#E2"`P``#E3"!X``#`
M/\/2X?#C,"`@`"3K[_$0``0'_@<'!P?K;_`P`"2Y!`"2XR`@*``$ZQ0``P`-
MN0@`$NQ1(+\`5;D$`(3C\/]@_W'C0)`P``2Y!`"SN3$`(:?$``2G2P`!XU"0
M*``DZQ@`'0`,N0@`%.,0D#``)$%PD#CC$)!X`!*G=``][(P`8C]^[&C_P`#8
MB&``!NP6``$`V.P1'[D&6>RA_\``V4'1L`#KJ@`&``RGJP`!TC]P`+``N00`
M*4&PL$#`Y?__]`^GI__VIXK_P(E@``:Y^6!HN10`AKD$`#VY!``GN00`2,#E
M___7^%"`D'CK;_#0``0'_J>H`$`;H1FHN00`)[GRL*BY&``AN10`:KD$`#NY
M!`!&P.7__]??&!I:$)!X4!"0>.P6_^1`?AN*N00`*;D(`+:Y%`"(P.7___/1
MI_3_H+D$`-NG]/_(ZX_P0``DXY`P*``$N00`L^.`,#``!.PY.K\]6;D4`!-!
M$;`XDH`0`*<Z``'C\/]@_W&Y%``3N00`HD$1L#CL/`!=.'ZG2`!`N?DP).Q#
M`!"`=J<J___K,@`(`-[L-@!M`'ZY%@`BQB````!QN00`*\#E___SD-<WL#BP
M.$*`L'-"D+!WZQ@`&``,0A"P<.L8`!``#$(0L''K&0`8``Q"$+!TZX@`"``,
M0H"P<NL9`!``#$(0L'7KF0`(``Q"D+!VN00`*\#E___S9M(#H`"P!+D$`"O2
M`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__UMNG2``XN?DP).Q#
M_[Z`=J<J___K,@`(`-[L-@`*`'ZY%@`BQB`````:I_3_KM?_$``0`$$0$0"G
M-O_[I_3_\M?_$``0`$$0$0"G-O_[I_3_C]<`$``0`-<`$``0``<'!P<'!P<'
M!P<'!^M_\#@`)./P_V#_<;D$`)*Y!`"#N00`=,#E___3>,"P```L?<`0```L
M=KD)`+'KNP`#``KLN``3`'RY!`"AXQ"@```$N00`1[D$`#BY!``IIZL`"`WA
MI[?_].M_\-@`!`?^!P<'!P<'!P<'!P<'!P<'_@<'!P<'!P<'!P<'!P<'Q%@`
M`"YTP/3__]0A!P<'!^MO\#``)+D$`!^G^_]@XQ#P```DP,```"U&!P?C0/$0
M``3K;_#0``0']`<'``(``2]T;7```"X`4$%27U1-4$1)4@``5$5-4$1)4@!4
M35``55-%4@``55-%4DY!344``"5S+R5S`"]P<F]C+W-E;&8O97AE``!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4```4$%27U!23T=.04U%```Z`"\`
M4$523#5,24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)3P``4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!
M0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```Q`%!!4E]#3$5!3CT``$Q$
M7TQ)0E)!4EE?4$%42`!365-414T``%!!5$@``"4P,G@``"5S)7,E<R5S``!P
M87(M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!P87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```8`'!E<FP``#``4$%2.CI0
M86-K97(Z.E9%4E-)3TX``#$N,#4R`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M90``+2T``&5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C
M(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P
M;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S
M=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N
M:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@
M/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM
M>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S
M(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@
M)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K
M(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D[
M"FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF
M("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`[
M"G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U
M=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D
M(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D[
M"B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*
M?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L
M92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M
M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD
M969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?
M<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&
M2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q
M=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@
M9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I
M(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO
M*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S
M>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R
M:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D
M;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L
M;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D
M("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U
M=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT
M96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*
M;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12([
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D
M4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N
M(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R
M;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI
M.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U
M9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@
M1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE
M(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D
M("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T
M96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR
M971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R
M;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%
M?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=0
M05)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U
M8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("````$;`SL```#@````&___;OP```5H__]Q3````/S_
M_W)\```!+/__<VP```&,__]U;````<C__W9L```""/__=NP```)$__]ZC```
M`IC__WK,```"N/__>[P```+\__][S````Q#__W\,```#4/__?UP```-P__^`
MS````Y3__XP,```#U/__C.P```0(__^-'```!"C__X[\```$B/__GKP```3H
M__^B;```!2C__Z;<```%K/__O:P```7L__^^'```!A#__[],```&3/__P*P`
M``:$___!'```!KS__\$L```&U````!0``````7I2``%X#@$;#`^@`0<.````
M`!0````<__]P2````$8``````````````!0``````7I2``%X#@$;#`^@`0``
M`````%P````<__]Q2````.(`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[(`@*>
M"L_.S<S+RLG(Q\8.H`%""UP*S\[-S,O*R<C'Q@Z@`4(+3@K/SLW,R\K)R,?&
M#J`!0@L``````#@```!\__]QV````?8`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M2@[@`W(*S\[-S,O*R<C'Q@Z@`4(+`````#P```"X__]SG````/H`1H<-B`R)
M"XH*BPF,"(T'C@:/!48.H"%0#L@B`LX*S\[-S,O*R<C'#J`!0@L````````X
M````^/__=%P```!X`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4P.R`("9,_.S<S+
MRLG(Q\8.H`$```````!0```!-/__=*````.@`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!4H.X`)(F!4#`F@*S\[-S,O*R<C'QM@.H`%""P,!',_.S<S+RLG(Q\;8
M#J`!```````<```!B/__=^P````\`$R.!H\%1@[``F3/S@Z@`0```$````&H
M__]X#````.X`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z@(4P.H$%0#MA"`K8*
MS\[-S,O*R<C'Q@Z@`4(+````$````>S__WBX````!@`````````\```"`/__
M>+0```,T`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.H"%0#N@C`M8*S\[-S,O*
MR<C'Q@Z@`4(+````'````D#__WNT````4`!4"0\01@[(`F[/#J`!```````@
M```"8/__>^0```%N``,!$HX&CP5&#L`"8,_.#J`!```````\```"A/__?3``
M``LR`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.\`(#"EX*S\[-S,O*R<C'Q@Z@
M`4(+````````,````L3__X@P````W@!>B0N*"HL)C`B-!XX&CP5&#L`"`HH*
MS\[-S,O*R0Z@`4(+`````!P```+X__^(W````"P`1HX&CP5&#L`"7L_.#J`!
M````7````QC__XCL```!W`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`H@*
MS\[-S,O*R<C'Q@Z@`48+9@K/SLW,R\K)R,?&#J`!0@L#`0[/SLW,R\K)R,?&
M#J`!````````7````WC__XIL```/N@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#`Z@@0)<#0]&#KB%`E28%0,#6@K/SLW,R\K)R,?&V`Z@`48+`P2<"L_.S<S+
MRLG(Q\;8#J`!0@L`````/````]C__YG,```#J`!&A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5,#L`"`P+>"L_.S<S+RLG(Q\8.H`%""P```````#P```08__^=/```
M!&@`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[H`P,!-`K/SLW,R\K)R,?&#J`!
M0@L```````!````$6/__:8P```)(`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.
MZ`(#`:`*S\[-S,O*R<C'Q@Z@`4(+`````````````#P```2<__^A*```%L8`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[0!P,6K@K/SLW,R\K)R,?&#J`!0@L`
M```````@```$W/__M[@```!L`$J.!H\%1@[``@):S\X.H`$````````X```%
M`/__N`0```$P`$:&#H<-B`R)"XH*BPF,"(T'C@:/!60.P`("K@K/SLW,R\K)
MR,?&#J`!0@L````T```%//__N/@```%4`$:(#(D+B@J+"8P(C0>.!H\%;`[`
M`@+`"L_.S<S+RLG(#J`!1@L``````#0```5T__^Z(````&(`1H<-B`R)"XH*
MBPF,"(T'C@:/!48.P`("5,_.S<S+RLG(QPZ@`0``````%```!:S__[I8````
M`@``````````````$```!<3__[I0````#```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````)&``````
M```D$``````````!`````````N0``````````0````````+T``````````$`
M```````#!``````````,````````&:@`````````#0```````',P````````
M`!D```````#+L``````````;``````````@`````````&@```````,NX````
M`````!P`````````"`````!O__[U`````````I``````````!0````````QP
M``````````8````````#<``````````*````````!((`````````"P``````
M```8`````````!4````````````````````#````````S=```````````@``
M``````4H`````````!0`````````!P`````````7````````%(``````````
M!P```````!(H``````````@````````"6``````````)`````````!@`````
M````'@`````````(`````&____L`````"````0````!O___^````````$;@`
M````;____P`````````"`````&____`````````0\@````!O___Y````````
M``X`````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````,O`
M`````````````````````````````!H6````````&C8````````:5@``````
M`!IV````````&I8````````:M@```````!K6````````&O8````````;%@``
M`````!LV````````&U8````````;=@```````!N6````````&[8````````;
MU@```````!OV````````'!8````````<-@```````!Q6````````''8`````
M```<E@```````!RV````````'-8````````<]@```````!T6````````'38`
M```````=5@```````!UV````````'98````````=M@```````!W6````````
M'?8````````>%@```````!XV````````'E8````````>=@```````!Z6````
M````'K8````````>U@```````![V````````'Q8````````?-@```````!]6
M````````'W8````````?E@```````!^V````````']8````````?]@``````
M`"`6````````(#8````````@5@```````"!V````````()8````````@M@``
M`````"#6````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"#P``````````````````#0"/____\`````````````<V``
M``````!S9@``````````````````<V@```````!S;````````'-T````````
M<^P```````!S?```````````````````<X````````!SA@``````````````
M````=DA'0T,Z("A58G5N='4@,3`N,BXQ+3$X=6)U;G1U,BD@,3`N,BXQ(#(P
M,C$P,3,P```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`
M+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M````````````````````````````````````````````````````````````
M"P````$``````````@````````(X`````````C@`````````#P``````````
M``````````$``````````````!,````'``````````(````````"2```````
M``)(`````````"0````````````````````$```````````````F````!P``
M```````"`````````FP````````";``````````@````````````````````
M!```````````````-&____8``````````@````````*0`````````I``````
M````X`````4```````````````@``````````````#X````+``````````(`
M```````#<`````````-P````````"0`````&`````@`````````(````````
M`!@```!&`````P`````````"````````#'`````````,<`````````2"````
M`````````````````0``````````````3F____\``````````@```````!#R
M````````$/(`````````P`````4```````````````(``````````@```%MO
M___^``````````(````````1N````````!&X`````````'`````&`````@``
M```````(``````````````!J````!``````````"````````$B@````````2
M*`````````)8````!0``````````````"``````````8````=`````0`````
M````0@```````!2`````````%(`````````%*`````4````5``````````@`
M````````&````'X````!``````````8````````9J````````!FH````````
M`$`````````````````````$``````````````!Y`````0`````````&````
M````&>@````````9Z`````````<`````````````````````!``````````@
M````A`````$`````````!@```````"#P````````(/````````!20```````
M`````````````!```````````````(H````!``````````8```````!S,```
M`````',P`````````"P````````````````````$``````````````"0````
M`0`````````"````````<UP```````!S7````````#Z8````````````````
M````!```````````````F`````$``````````@```````+'T````````L?0`
M````````Y`````````````````````0``````````````*8````!````````
M``(```````"RV````````++8````````!@@````````````````````(````
M``````````"P````#@`````````#````````R[````````"[L``````````(
M````````````````````"``````````(````O`````\``````````P``````
M`,NX````````N[@`````````"`````````````````````@`````````"```
M`,@````&``````````,```````#+P````````+O``````````A`````&````
M```````````(`````````!````#1`````0`````````#````````S=``````
M``"]T`````````(P````````````````````"``````````(````U@````$`
M`````````P```````-``````````P```````````@```````````````````
M``@``````````````-P````(``````````,```````#0@````````,"`````
M````$"@````````````````````(``````````````#A`````0`````````P
M``````````````````#`@``````````O`````````````````````0``````
M```!`````0````,`````````````````````````````P*\`````````Z@``
6``````````````````$`````````````
